==> ima-predeployed-1.0.0a243.tar.gz: ima-predeployed-1.0.0a243/src/ima_predeployed/addresses.py <==
PROXY_ADMIN_ADDRESS = '0xd2aAa00000000000000000000000000000000000'
MESSAGE_PROXY_FOR_SCHAIN_ADDRESS = '0xd2AAa00100000000000000000000000000000000'
MESSAGE_PROXY_FOR_SCHAIN_IMPLEMENTATION_ADDRESS = '0xD2AAa001D2000000000000000000000000000000'
KEY_STORAGE_ADDRESS = '0xd2aaa00200000000000000000000000000000000'
KEY_STORAGE_IMPLEMENTATION_ADDRESS = '0xD2AAa002d2000000000000000000000000000000'
COMMUNITY_LOCKER_ADDRESS = '0xD2aaa00300000000000000000000000000000000'
COMMUNITY_LOCKER_IMPLEMENTATION_ADDRESS = '0xD2aaA003d2000000000000000000000000000000'
TOKEN_MANAGER_ETH_ADDRESS = '0xd2AaA00400000000000000000000000000000000'
TOKEN_MANAGER_ETH_IMPLEMENTATION_ADDRESS = '0xd2AaA004d2000000000000000000000000000000'
TOKEN_MANAGER_ERC20_ADDRESS = '0xD2aAA00500000000000000000000000000000000'
TOKEN_MANAGER_ERC20_IMPLEMENTATION_ADDRESS = '0xd2aAa005d2000000000000000000000000000000'
TOKEN_MANAGER_ERC721_ADDRESS = '0xD2aaa00600000000000000000000000000000000'
TOKEN_MANAGER_ERC721_IMPLEMENTATION_ADDRESS = '0xd2AAa006d2000000000000000000000000000000'
ETH_ERC20_ADDRESS = '0xD2Aaa00700000000000000000000000000000000'
ETH_ERC20_IMPLEMENTATION_ADDRESS = '0xD2aaA007d2000000000000000000000000000000'
TOKEN_MANAGER_LINKER_ADDRESS = '0xD2aAA00800000000000000000000000000000000'
TOKEN_MANAGER_LINKER_IMPLEMENTATION_ADDRESS = '0xd2aAA008D2000000000000000000000000000000'
TOKEN_MANAGER_ERC1155_ADDRESS = '0xD2aaA00900000000000000000000000000000000'
TOKEN_MANAGER_ERC1155_IMPLEMENTATION_ADDRESS = '0xD2AaA009d2000000000000000000000000000000'

==> ima-predeployed-1.3.0b4.tar.gz: ima-predeployed-1.3.0b4/src/ima_predeployed/addresses.py <==
PROXY_ADMIN_ADDRESS = '0xd2aAa00000000000000000000000000000000000'
MESSAGE_PROXY_FOR_SCHAIN_ADDRESS = '0xd2AAa00100000000000000000000000000000000'
MESSAGE_PROXY_FOR_SCHAIN_IMPLEMENTATION_ADDRESS = '0xD2AAa001D2000000000000000000000000000000'
KEY_STORAGE_ADDRESS = '0xd2aaa00200000000000000000000000000000000'
KEY_STORAGE_IMPLEMENTATION_ADDRESS = '0xD2AAa002d2000000000000000000000000000000'
COMMUNITY_LOCKER_ADDRESS = '0xD2aaa00300000000000000000000000000000000'
COMMUNITY_LOCKER_IMPLEMENTATION_ADDRESS = '0xD2aaA003d2000000000000000000000000000000'
TOKEN_MANAGER_ETH_ADDRESS = '0xd2AaA00400000000000000000000000000000000'
TOKEN_MANAGER_ETH_IMPLEMENTATION_ADDRESS = '0xd2AaA004d2000000000000000000000000000000'
TOKEN_MANAGER_ERC20_ADDRESS = '0xD2aAA00500000000000000000000000000000000'
TOKEN_MANAGER_ERC20_IMPLEMENTATION_ADDRESS = '0xd2aAa005d2000000000000000000000000000000'
TOKEN_MANAGER_ERC721_ADDRESS = '0xD2aaa00600000000000000000000000000000000'
TOKEN_MANAGER_ERC721_IMPLEMENTATION_ADDRESS = '0xd2AAa006d2000000000000000000000000000000'
ETH_ERC20_ADDRESS = '0xD2Aaa00700000000000000000000000000000000'
ETH_ERC20_IMPLEMENTATION_ADDRESS = '0xD2aaA007d2000000000000000000000000000000'
TOKEN_MANAGER_LINKER_ADDRESS = '0xD2aAA00800000000000000000000000000000000'
TOKEN_MANAGER_LINKER_IMPLEMENTATION_ADDRESS = '0xd2aAA008D2000000000000000000000000000000'
TOKEN_MANAGER_ERC1155_ADDRESS = '0xD2aaA00900000000000000000000000000000000'
TOKEN_MANAGER_ERC1155_IMPLEMENTATION_ADDRESS = '0xD2AaA009d2000000000000000000000000000000'
TOKEN_MANAGER_ERC721_WITH_METADATA_ADDRESS = '0xd2AaA00a00000000000000000000000000000000'
TOKEN_MANAGER_ERC721_WITH_METADATA_IMPLEMENTATION_ADDRESS = '0xd2AAA00Ad2000000000000000000000000000000'
